#ifdef OPENGL_ES
precision mediump float;
#endif

varying vec2 v_texCoord;

uniform float _waveWidth;
uniform float _waveAmplitude;   
uniform float _curWaveDis;  
uniform float _screenRatio;
uniform vec4 _startPos; 

void main()
{
    //计算uv到中间点的向量(向外扩，反过来就是向里缩)  
	vec2 dv = _startPos.xy - v_texCoord.xy;  
	//按照屏幕长宽比进行缩放  
	dv = dv * vec2(_screenRatio, 1);  
	//计算像素点距中点的距离  
	float dis = sqrt(dv.x * dv.x + dv.y * dv.y); 
 
	//用sin函数计算出波形的偏移值factor  
	//dis在这里都是小于1的，所以我们需要乘以一个比较大的数，比如60，这样就有多个波峰波谷  
	//sin函数是（-1，1）的值域，我们希望偏移值很小，所以这里我们缩小100倍，据说乘法比较快,so...  
	float wa = clamp(dis,0.4,0.8);
	
	float sinFactor = exp(wa * wa * _waveAmplitude) * 0.05;
	//距离当前波纹运动点的距离，如果小于waveWidth才予以保留，否则已经出了波纹范围，factor通过clamp设置为0 
	float waveFactor = (_waveWidth - abs(_curWaveDis - dis)) / _waveWidth;
	
	float discardFactor = clamp(waveFactor,0.0,1.0);
 
	//计算每个像素uv的偏移值  
	vec2 offset = dv  * sinFactor * discardFactor;  
	//像素采样时偏移offset  
	vec2 uv = offset + v_texCoord.xy;  
	
	gl_FragColor = texture2D(CC_Texture0, uv);
}
